def get_main_parser():
    """The main parser for Jina
    :return: the parser
    """
    from .base import set_base_parser
    from .helper import _chf
    from .token import set_token_parser

    # create the top-level parser
    parser = set_base_parser()

    sp = parser.add_subparsers(
        dest='cli',
        required=True,
    )

    sp.add_parser(
        'login',
        description='Login to Jina Ecosystem',
        formatter_class=_chf,
    )

    sp.add_parser(
        'logout',
        description='Logout Jina Ecosystem',
        formatter_class=_chf,
    )

    set_token_parser(
        sp.add_parser(
            'token',
            description='Operations on Personal Access Token',
            formatter_class=_chf,
        )
    )

    return parser



def main():
    import os

    from auth.parsers import get_main_parser

    args = get_main_parser().parse_args()

    if args.log_level:
        os.environ['JINA_AUTH_LOG_LEVEL'] = args.log_level

    try:
        # TODO: enable verify latest version after publishing package

        # import threading
        # from .helper import is_latest_version

        # threading.Thread(
        #     target=is_latest_version, daemon=True, args=('jina-auth',)
        # ).start()
        from auth import api

        getattr(api, args.cli.replace('-', '_'))(args)
    except KeyboardInterrupt:
        pass


if __name__ == '__main__':
    main()



import argparse
import importlib.metadata


def set_base_parser():
    from auth.parsers.helper import _chf, colored

    __version__ = importlib.metadata.version("jina-auth")

    parser = argparse.ArgumentParser(
        description=f'Jina auth (v{colored(__version__, "green")}) helps you login in to Jina Ecosystem.',  # noqa F501
        formatter_class=_chf,
    )
    parser.add_argument(
        '-v',
        '--version',
        action='version',
        version=__version__,
        help='Show version',
    )
    parser.add_argument(
        '--log-level',
        type=str,
        choices=['DEBUG', 'INFO', 'CRITICAL', 'NOTSET'],
        default='INFO',
        help='Set the loglevel of the logger',
    )
    return parser
